#! /usr/local/bin/python

from roboter_C import *

class Roboter_Modell_S(Roboter_Modell_C):
   def __init__(self,welt):
      Roboter.__init__(self,welt)                  

   def vorne_rechts_frei(self):
      self.rechts()
      if self.vorne_frei():
         self.vor()
         self.links()
         zustand=self.vorne_frei()
         self.links()
         self.vor()
         self.rechts()
         return zustand
      else:
         self.links()
         return 0
         
   def vorne_links_frei(self):
      self.links()
      if self.vorne_frei():
         self.vor()
         self.rechts()
         zustand=self.vorne_frei()
         self.rechts()
         self.vor()
         self.links()
         return zustand
      else:
         self.rechts()
         return 0
         
   def Stadion_gefunden(self):
      return self.vorne_links_frei() or self.vorne_rechts_frei()
      

   def markiere_dein_Heim(self):
      self.gib()

   def suche_das_Stadion(self):
      mein_Roboter.vor_bis_Hindernis()
      while not mein_Roboter.Stadion_gefunden():
         mein_Roboter.Linkskurve()
         mein_Roboter.vor_bis_Hindernis()
         if mein_Roboter.Stadion_gefunden():
            break
         else:
            mein_Roboter.Rechtskurve()
            mein_Roboter.vor_bis_Hindernis()
   
   def suche_den_Eingang(self):
      self.rechts()
      while 1:
         while not self.links_frei():
            self.vor()
         self.links()
         self.vor()
         if not self.links_frei() and not self.rechts_frei():
            break

   def drehe_eine_Runde(self):
      self.vor(); self.rechts()
      self.vor_bis_Hindernis()
      self.links()
      self.vor_bis_Hindernis()
      self.links()
      self.vor_bis_Hindernis()
      self.links()
      self.vor_bis_Hindernis()
      self.links()
      while not self.rechts_frei():
         self.vor()
      self.rechts()

   def gehe_nach_Hause(self):
      self.vor_bis_Hindernis()
      self.links()
      while self.Feld_leer():
         self.vor_bis_Hindernis()
         self.links()
      pass

meine_Welt=Welt("stadion.welt")
mein_Roboter=Roboter_Modell_S(meine_Welt)

mein_Roboter.markiere_dein_Heim()
mein_Roboter.suche_das_Stadion()
mein_Roboter.suche_den_Eingang()
mein_Roboter.drehe_eine_Runde()
mein_Roboter.gehe_nach_Hause()

Tkinter.mainloop()
